@@ -1,10 +1,11 @@
 import os
+import shutil
 
 import blah.systems
 import blah.uri_parser
 import blah.errors
 
-def fetch(uri_str, local_path, use_cache=False, systems=None):
+def fetch(uri_str, local_path, archive=False, use_cache=False, systems=None):
     if systems is None:
         systems = blah.systems.all_systems
     
@@ -16,6 +17,8 @@ def fetch(uri_str, local_path, use_cache=False, systems=None):
     local_repo = _fetch_all_revisions(uri, local_path, vcs)
     revision = _read_revision(vcs, uri)
     local_repo.checkout_revision(revision)
+    if archive:
+        shutil.rmtree(os.path.join(local_path, vcs.directory_name))
 
 def _find_vcs(uri, systems):
     for vcs in systems:
